
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcoreaddons_python.h"

// main header
#include "kaboutdata_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <kaboutdata.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

extern "C" {
static PyTypeObject *Sbk_KAboutData_TypeF(void)
{
    return SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KAboutData_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KAboutData >()))
        return -1;

    ::KAboutData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:KAboutData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: KAboutData::KAboutData(const KAboutData&)
    // 1: KAboutData::KAboutData(const QString&=,const QString&=,const QString&=)
    if (numArgs == 0) {
        overloadId = 1; // KAboutData(QString,QString,QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // KAboutData(QString,QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // KAboutData(QString,QString,QString)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                overloadId = 1; // KAboutData::KAboutData(const QString&=,const QString&=,const QString&=)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), (pyArgs[0])))) {
        overloadId = 0; // KAboutData::KAboutData(const KAboutData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Resolve keyword arguments
    switch (overloadId) {
        case 0: // KAboutData::KAboutData(const KAboutData&)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
            }
            break;
        }
        case 1: // KAboutData::KAboutData(const QString&=,const QString&=,const QString&=)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[3] = {{"componentName", 0}, {"displayName", 1}, {"version", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 3, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))))
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))))
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
                }
            }
            break;
        }
    }

    // PyMI support
    Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // KAboutData(const KAboutData &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KAboutData cppArg0_local;
            ::KAboutData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::KAboutData(const KAboutData&)
                cptr = new ::KAboutData(*cppArg0);
            }
            break;
        }
        case 1: // KAboutData(const QString &componentName, const QString &displayName, const QString &version)
        {
            ::QString cppArg0{};
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2{};
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::KAboutData(const QString&=,const QString&=,const QString&=)
                cptr = new ::KAboutData(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::KAboutData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KAboutDataFunc_aboutTranslationTeam([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static KAboutData::aboutTranslationTeam()->QString
        QString cppResult = ::KAboutData::aboutTranslationTeam();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_addAuthor(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addAuthor", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:addAuthor", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: KAboutData::addAuthor(const KAboutPerson&)->KAboutData&
    // 1: KAboutData::addAuthor(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
    // 2: KAboutData::addAuthor(const QString&,const QString&=,const QString&=,const QString&=,const QUrl&=)->KAboutData&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // addAuthor(QString,QString,QString,QString,QUrl)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // addAuthor(QString,QString,QString,QString,QUrl)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // addAuthor(QString,QString,QString,QString,QUrl)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 2; // addAuthor(QString,QString,QString,QString,QUrl)
                    } else if (numArgs == 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        overloadId = 1; // KAboutData::addAuthor(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[4])))) {
                        overloadId = 2; // KAboutData::addAuthor(const QString&,const QString&=,const QString&=,const QString&=,const QUrl&=)->KAboutData&
                    }
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutPerson_IDX]), (pyArgs[0])))) {
        overloadId = 0; // KAboutData::addAuthor(const KAboutPerson&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addAuthor", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addAuthor(const KAboutPerson &author)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addAuthor", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::KAboutPerson cppArg0_local;
            ::KAboutPerson *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addAuthor(const KAboutPerson&)->KAboutData&
                KAboutData & cppResult = cppSelf->addAuthor(*cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 1: // addAuthor(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QString &kdeStoreUsername)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addAuthor", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addAuthor(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
                KAboutData & cppResult = cppSelf->addAuthor(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 2: // addAuthor(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QUrl &avatarUrl)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[4] = {{"task", 1}, {"emailAddress", 2}, {"webAddress", 3}, {"avatarUrl", 4}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 4, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))))
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))))
                    || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))))
                    || (pyArgs[4] != nullptr && !((pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[4])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addAuthor", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QUrl cppArg4_local = QUrl();
            ::QUrl *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4]) {
                if (pythonToCpp[4].isValue())
                    pythonToCpp[4](pyArgs[4], &cppArg4_local);
                else
                    pythonToCpp[4](pyArgs[4], &cppArg4);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addAuthor(const QString&,const QString&=,const QString&=,const QString&=,const QUrl&=)->KAboutData&
                KAboutData & cppResult = cppSelf->addAuthor(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_addComponent(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addComponent", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:addComponent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: KAboutData::addComponent(const KAboutComponent&)->KAboutData&
    // 1: KAboutData::addComponent(const QString&,const QString&=,const QString&=,const QString&=,KAboutLicense::LicenseKey=)->KAboutData&
    // 2: KAboutData::addComponent(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // addComponent(QString,QString,QString,QString,KAboutLicense::LicenseKey)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // addComponent(QString,QString,QString,QString,KAboutLicense::LicenseKey)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // addComponent(QString,QString,QString,QString,KAboutLicense::LicenseKey)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 1; // addComponent(QString,QString,QString,QString,KAboutLicense::LicenseKey)
                    } else if (numArgs == 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        overloadId = 2; // KAboutData::addComponent(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_LicenseKey_IDX]))), (pyArgs[4])))) {
                        overloadId = 1; // KAboutData::addComponent(const QString&,const QString&=,const QString&=,const QString&=,KAboutLicense::LicenseKey=)->KAboutData&
                    }
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutComponent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // KAboutData::addComponent(const KAboutComponent&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addComponent", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addComponent(const KAboutComponent &component)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addComponent", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::KAboutComponent cppArg0_local;
            ::KAboutComponent *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addComponent(const KAboutComponent&)->KAboutData&
                KAboutData & cppResult = cppSelf->addComponent(*cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 1: // addComponent(const QString &name, const QString &description, const QString &version, const QString &webAddress, KAboutLicense::LicenseKey licenseKey)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[4] = {{"description", 1}, {"version", 2}, {"webAddress", 3}, {"licenseKey", 4}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 4, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))))
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))))
                    || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))))
                    || (pyArgs[4] != nullptr && !((pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_LicenseKey_IDX]))), (pyArgs[4])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addComponent", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            ::KAboutLicense::LicenseKey cppArg4(KAboutLicense::Unknown);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addComponent(const QString&,const QString&=,const QString&=,const QString&=,KAboutLicense::LicenseKey=)->KAboutData&
                KAboutData & cppResult = cppSelf->addComponent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 2: // addComponent(const QString &name, const QString &description, const QString &version, const QString &webAddress, const QString &pathToLicenseFile)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addComponent", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addComponent(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
                KAboutData & cppResult = cppSelf->addComponent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_addCredit(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addCredit", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:addCredit", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: KAboutData::addCredit(const KAboutPerson&)->KAboutData&
    // 1: KAboutData::addCredit(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
    // 2: KAboutData::addCredit(const QString&,const QString&=,const QString&=,const QString&=,const QUrl&=)->KAboutData&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // addCredit(QString,QString,QString,QString,QUrl)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // addCredit(QString,QString,QString,QString,QUrl)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // addCredit(QString,QString,QString,QString,QUrl)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 2; // addCredit(QString,QString,QString,QString,QUrl)
                    } else if (numArgs == 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        overloadId = 1; // KAboutData::addCredit(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[4])))) {
                        overloadId = 2; // KAboutData::addCredit(const QString&,const QString&=,const QString&=,const QString&=,const QUrl&=)->KAboutData&
                    }
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutPerson_IDX]), (pyArgs[0])))) {
        overloadId = 0; // KAboutData::addCredit(const KAboutPerson&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addCredit", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addCredit(const KAboutPerson &person)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addCredit", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::KAboutPerson cppArg0_local;
            ::KAboutPerson *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addCredit(const KAboutPerson&)->KAboutData&
                KAboutData & cppResult = cppSelf->addCredit(*cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 1: // addCredit(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QString &kdeStoreUsername)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addCredit", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addCredit(const QString&,const QString&,const QString&,const QString&,const QString&)->KAboutData&
                KAboutData & cppResult = cppSelf->addCredit(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 2: // addCredit(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QUrl &avatarUrl)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[4] = {{"task", 1}, {"emailAddress", 2}, {"webAddress", 3}, {"avatarUrl", 4}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 4, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))))
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))))
                    || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))))
                    || (pyArgs[4] != nullptr && !((pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[4])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addCredit", errInfo, SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QUrl cppArg4_local = QUrl();
            ::QUrl *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4]) {
                if (pythonToCpp[4].isValue())
                    pythonToCpp[4](pyArgs[4], &cppArg4_local);
                else
                    pythonToCpp[4](pyArgs[4], &cppArg4);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addCredit(const QString&,const QString&=,const QString&=,const QString&=,const QUrl&=)->KAboutData&
                KAboutData & cppResult = cppSelf->addCredit(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_addLicense(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addLicense", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: KAboutData::addLicense(KAboutLicense::LicenseKey)->KAboutData&
    // 1: KAboutData::addLicense(KAboutLicense::LicenseKey,KAboutLicense::VersionRestriction)->KAboutData&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_LicenseKey_IDX]))), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addLicense(KAboutLicense::LicenseKey)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_VersionRestriction_IDX]))), (pyArgs[1])))) {
            overloadId = 1; // KAboutData::addLicense(KAboutLicense::LicenseKey,KAboutLicense::VersionRestriction)->KAboutData&
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addLicense", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addLicense(KAboutLicense::LicenseKey licenseKey)
        {
            ::KAboutLicense::LicenseKey cppArg0{KAboutLicense::Unknown};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addLicense(KAboutLicense::LicenseKey)->KAboutData&
                KAboutData & cppResult = cppSelf->addLicense(cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 1: // addLicense(KAboutLicense::LicenseKey licenseKey, KAboutLicense::VersionRestriction versionRestriction)
        {
            ::KAboutLicense::LicenseKey cppArg0{KAboutLicense::Unknown};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::KAboutLicense::VersionRestriction cppArg1{KAboutLicense::OnlyThisVersion};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::addLicense(KAboutLicense::LicenseKey,KAboutLicense::VersionRestriction)->KAboutData&
                KAboutData & cppResult = cppSelf->addLicense(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_addLicenseText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::addLicenseText(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::addLicenseText(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addLicenseText", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::addLicenseText(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->addLicenseText(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_addLicenseTextFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::addLicenseTextFile(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::addLicenseTextFile(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addLicenseTextFile", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::addLicenseTextFile(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->addLicenseTextFile(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_applicationData([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static KAboutData::applicationData()->KAboutData
        KAboutData cppResult = ::KAboutData::applicationData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_authors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::authors()const->QList<KAboutPerson>
        QList<KAboutPerson> cppResult = const_cast<const ::KAboutData *>(cppSelf)->authors();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCoreAddonsTypeConverters[SBK_KCoreAddons_QList_KAboutPerson_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_bugAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::bugAddress()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->bugAddress();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_componentName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::componentName()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->componentName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_components(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::components()const->QList<KAboutComponent>
        QList<KAboutComponent> cppResult = const_cast<const ::KAboutData *>(cppSelf)->components();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCoreAddonsTypeConverters[SBK_KCoreAddons_QList_KAboutComponent_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_copyrightStatement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::copyrightStatement()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->copyrightStatement();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_credits(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::credits()const->QList<KAboutPerson>
        QList<KAboutPerson> cppResult = const_cast<const ::KAboutData *>(cppSelf)->credits();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCoreAddonsTypeConverters[SBK_KCoreAddons_QList_KAboutPerson_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_customAuthorPlainText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::customAuthorPlainText()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->customAuthorPlainText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_customAuthorRichText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::customAuthorRichText()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->customAuthorRichText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_customAuthorTextEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::customAuthorTextEnabled()const->bool
        bool cppResult = const_cast<const ::KAboutData *>(cppSelf)->customAuthorTextEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_desktopFileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::desktopFileName()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->desktopFileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_displayName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::displayName()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->displayName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_fromAppStreamFile([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static KAboutData::fromAppStreamFile(const QString&)->KAboutData
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // static KAboutData::fromAppStreamFile(const QString&)->KAboutData
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromAppStreamFile", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static KAboutData::fromAppStreamFile(const QString&)->KAboutData
            KAboutData cppResult = ::KAboutData::fromAppStreamFile(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_fromAppStreamForApplication([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static KAboutData::fromAppStreamForApplication()->KAboutData
        KAboutData cppResult = ::KAboutData::fromAppStreamForApplication();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_fromAppStreamId([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static KAboutData::fromAppStreamId(const QString&)->KAboutData
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // static KAboutData::fromAppStreamId(const QString&)->KAboutData
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromAppStreamId", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static KAboutData::fromAppStreamId(const QString&)->KAboutData
            KAboutData cppResult = ::KAboutData::fromAppStreamId(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_homepage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::homepage()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->homepage();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_internalBugAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::internalBugAddress()const->const char*
        const char * cppResult = const_cast<const ::KAboutData *>(cppSelf)->internalBugAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_internalProductName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::internalProductName()const->const char*
        const char * cppResult = const_cast<const ::KAboutData *>(cppSelf)->internalProductName();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_internalProgramName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::internalProgramName()const->const char*
        const char * cppResult = const_cast<const ::KAboutData *>(cppSelf)->internalProgramName();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_internalVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::internalVersion()const->const char*
        const char * cppResult = const_cast<const ::KAboutData *>(cppSelf)->internalVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_licenses(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::licenses()const->QList<KAboutLicense>
        QList<KAboutLicense> cppResult = const_cast<const ::KAboutData *>(cppSelf)->licenses();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCoreAddonsTypeConverters[SBK_KCoreAddons_QList_KAboutLicense_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_organizationDomain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::organizationDomain()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->organizationDomain();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_otherText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::otherText()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->otherText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_processCommandLine(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::processCommandLine(QCommandLineParser*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), (pyArg)))) {
        overloadId = 0; // KAboutData::processCommandLine(QCommandLineParser*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "processCommandLine", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCommandLineParser *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::processCommandLine(QCommandLineParser*)
            cppSelf->processCommandLine(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KAboutDataFunc_productName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::productName()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->productName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_programLogo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::programLogo()const->QVariant
        QVariant cppResult = const_cast<const ::KAboutData *>(cppSelf)->programLogo();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setApplicationData([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static KAboutData::setApplicationData(const KAboutData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), (pyArg)))) {
        overloadId = 0; // static KAboutData::setApplicationData(const KAboutData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setApplicationData", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KAboutData cppArg0_local;
        ::KAboutData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static KAboutData::setApplicationData(const KAboutData&)
            ::KAboutData::setApplicationData(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KAboutDataFunc_setBugAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setBugAddress(const QByteArray&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // KAboutData::setBugAddress(const QByteArray&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBugAddress", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setBugAddress(const QByteArray&)->KAboutData&
            KAboutData & cppResult = cppSelf->setBugAddress(*cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setComponentName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setComponentName(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setComponentName(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComponentName", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setComponentName(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setComponentName(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setCopyrightStatement(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setCopyrightStatement(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setCopyrightStatement(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCopyrightStatement", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setCopyrightStatement(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setCopyrightStatement(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setCustomAuthorText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCustomAuthorText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: KAboutData::setCustomAuthorText(const QString&,const QString&)->KAboutData&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // KAboutData::setCustomAuthorText(const QString&,const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCustomAuthorText", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setCustomAuthorText(const QString&,const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setCustomAuthorText(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setDesktopFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setDesktopFileName(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setDesktopFileName(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDesktopFileName", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setDesktopFileName(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setDesktopFileName(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setDisplayName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setDisplayName(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setDisplayName(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDisplayName", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setDisplayName(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setDisplayName(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setHomepage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setHomepage(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setHomepage(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHomepage", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setHomepage(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setHomepage(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setLicense(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLicense", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: KAboutData::setLicense(KAboutLicense::LicenseKey)->KAboutData&
    // 1: KAboutData::setLicense(KAboutLicense::LicenseKey,KAboutLicense::VersionRestriction)->KAboutData&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_LicenseKey_IDX]))), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setLicense(KAboutLicense::LicenseKey)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_VersionRestriction_IDX]))), (pyArgs[1])))) {
            overloadId = 1; // KAboutData::setLicense(KAboutLicense::LicenseKey,KAboutLicense::VersionRestriction)->KAboutData&
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLicense", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setLicense(KAboutLicense::LicenseKey licenseKey)
        {
            ::KAboutLicense::LicenseKey cppArg0{KAboutLicense::Unknown};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::setLicense(KAboutLicense::LicenseKey)->KAboutData&
                KAboutData & cppResult = cppSelf->setLicense(cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
        case 1: // setLicense(KAboutLicense::LicenseKey licenseKey, KAboutLicense::VersionRestriction versionRestriction)
        {
            ::KAboutLicense::LicenseKey cppArg0{KAboutLicense::Unknown};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::KAboutLicense::VersionRestriction cppArg1{KAboutLicense::OnlyThisVersion};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // KAboutData::setLicense(KAboutLicense::LicenseKey,KAboutLicense::VersionRestriction)->KAboutData&
                KAboutData & cppResult = cppSelf->setLicense(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setLicenseText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setLicenseText(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setLicenseText(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLicenseText", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setLicenseText(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setLicenseText(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setLicenseTextFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setLicenseTextFile(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setLicenseTextFile(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLicenseTextFile", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setLicenseTextFile(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setLicenseTextFile(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setOrganizationDomain(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setOrganizationDomain(const QByteArray&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // KAboutData::setOrganizationDomain(const QByteArray&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOrganizationDomain", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setOrganizationDomain(const QByteArray&)->KAboutData&
            KAboutData & cppResult = cppSelf->setOrganizationDomain(*cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setOtherText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setOtherText(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setOtherText(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOtherText", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setOtherText(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setOtherText(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setProductName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setProductName(const QByteArray&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // KAboutData::setProductName(const QByteArray&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProductName", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setProductName(const QByteArray&)->KAboutData&
            KAboutData & cppResult = cppSelf->setProductName(*cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setProgramLogo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setProgramLogo(const QVariant&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setProgramLogo(const QVariant&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProgramLogo", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setProgramLogo(const QVariant&)->KAboutData&
            KAboutData & cppResult = cppSelf->setProgramLogo(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setShortDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setShortDescription(const QString&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // KAboutData::setShortDescription(const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShortDescription", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setShortDescription(const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setShortDescription(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setTranslator(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTranslator", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: KAboutData::setTranslator(const QString&,const QString&)->KAboutData&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // KAboutData::setTranslator(const QString&,const QString&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTranslator", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setTranslator(const QString&,const QString&)->KAboutData&
            KAboutData & cppResult = cppSelf->setTranslator(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setVersion(const QByteArray&)->KAboutData&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // KAboutData::setVersion(const QByteArray&)->KAboutData&
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVersion", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setVersion(const QByteArray&)->KAboutData&
            KAboutData & cppResult = cppSelf->setVersion(*cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_setupCommandLine(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: KAboutData::setupCommandLine(QCommandLineParser*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), (pyArg)))) {
        overloadId = 0; // KAboutData::setupCommandLine(QCommandLineParser*)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setupCommandLine", SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCommandLineParser *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // KAboutData::setupCommandLine(QCommandLineParser*)->bool
            bool cppResult = cppSelf->setupCommandLine(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_shortDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::shortDescription()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->shortDescription();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_translators(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::translators()const->QList<KAboutPerson>
        QList<KAboutPerson> cppResult = const_cast<const ::KAboutData *>(cppSelf)->translators();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCoreAddonsTypeConverters[SBK_KCoreAddons_QList_KAboutPerson_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_unsetCustomAuthorText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::unsetCustomAuthorText()->KAboutData&
        KAboutData & cppResult = cppSelf->unsetCustomAuthorText();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutDataFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // KAboutData::version()const->QString
        QString cppResult = const_cast<const ::KAboutData *>(cppSelf)->version();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KAboutData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_KAboutData_PropertyStrings[] = {
    "authors:",
    "bugAddress:",
    "componentName:",
    "components:",
    "copyrightStatement:",
    "credits:",
    "desktopFileName:",
    "displayName:",
    "homepage:",
    "licenses:",
    "otherText:",
    "productName:",
    "programLogo:",
    "shortDescription:",
    "translators:",
    "version:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KAboutData_methods[] = {
    {"aboutTranslationTeam", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_aboutTranslationTeam), METH_NOARGS|METH_STATIC, nullptr},
    {"addAuthor", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_addAuthor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addComponent", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_addComponent), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addCredit", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_addCredit), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addLicense", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_addLicense), METH_VARARGS, nullptr},
    {"addLicenseText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_addLicenseText), METH_O, nullptr},
    {"addLicenseTextFile", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_addLicenseTextFile), METH_O, nullptr},
    {"applicationData", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_applicationData), METH_NOARGS|METH_STATIC, nullptr},
    {"authors", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_authors), METH_NOARGS, nullptr},
    {"bugAddress", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_bugAddress), METH_NOARGS, nullptr},
    {"componentName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_componentName), METH_NOARGS, nullptr},
    {"components", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_components), METH_NOARGS, nullptr},
    {"copyrightStatement", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_copyrightStatement), METH_NOARGS, nullptr},
    {"credits", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_credits), METH_NOARGS, nullptr},
    {"customAuthorPlainText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_customAuthorPlainText), METH_NOARGS, nullptr},
    {"customAuthorRichText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_customAuthorRichText), METH_NOARGS, nullptr},
    {"customAuthorTextEnabled", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_customAuthorTextEnabled), METH_NOARGS, nullptr},
    {"desktopFileName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_desktopFileName), METH_NOARGS, nullptr},
    {"displayName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_displayName), METH_NOARGS, nullptr},
    {"fromAppStreamFile", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_fromAppStreamFile), METH_O|METH_STATIC, nullptr},
    {"fromAppStreamForApplication", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_fromAppStreamForApplication), METH_NOARGS|METH_STATIC, nullptr},
    {"fromAppStreamId", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_fromAppStreamId), METH_O|METH_STATIC, nullptr},
    {"homepage", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_homepage), METH_NOARGS, nullptr},
    {"internalBugAddress", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_internalBugAddress), METH_NOARGS, nullptr},
    {"internalProductName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_internalProductName), METH_NOARGS, nullptr},
    {"internalProgramName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_internalProgramName), METH_NOARGS, nullptr},
    {"internalVersion", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_internalVersion), METH_NOARGS, nullptr},
    {"licenses", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_licenses), METH_NOARGS, nullptr},
    {"organizationDomain", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_organizationDomain), METH_NOARGS, nullptr},
    {"otherText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_otherText), METH_NOARGS, nullptr},
    {"processCommandLine", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_processCommandLine), METH_O, nullptr},
    {"productName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_productName), METH_NOARGS, nullptr},
    {"programLogo", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_programLogo), METH_NOARGS, nullptr},
    {"setApplicationData", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setApplicationData), METH_O|METH_STATIC, nullptr},
    {"setBugAddress", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setBugAddress), METH_O, nullptr},
    {"setComponentName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setComponentName), METH_O, nullptr},
    {"setCopyrightStatement", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setCopyrightStatement), METH_O, nullptr},
    {"setCustomAuthorText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setCustomAuthorText), METH_VARARGS, nullptr},
    {"setDesktopFileName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setDesktopFileName), METH_O, nullptr},
    {"setDisplayName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setDisplayName), METH_O, nullptr},
    {"setHomepage", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setHomepage), METH_O, nullptr},
    {"setLicense", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setLicense), METH_VARARGS, nullptr},
    {"setLicenseText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setLicenseText), METH_O, nullptr},
    {"setLicenseTextFile", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setLicenseTextFile), METH_O, nullptr},
    {"setOrganizationDomain", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setOrganizationDomain), METH_O, nullptr},
    {"setOtherText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setOtherText), METH_O, nullptr},
    {"setProductName", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setProductName), METH_O, nullptr},
    {"setProgramLogo", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setProgramLogo), METH_O, nullptr},
    {"setShortDescription", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setShortDescription), METH_O, nullptr},
    {"setTranslator", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setTranslator), METH_VARARGS, nullptr},
    {"setVersion", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setVersion), METH_O, nullptr},
    {"setupCommandLine", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_setupCommandLine), METH_O, nullptr},
    {"shortDescription", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_shortDescription), METH_NOARGS, nullptr},
    {"translators", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_translators), METH_NOARGS, nullptr},
    {"unsetCustomAuthorText", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_unsetCustomAuthorText), METH_NOARGS, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_KAboutDataFunc_version), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_KAboutData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_KAboutData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KAboutData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KAboutData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KAboutData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KAboutData_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KAboutData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KAboutData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_KAboutData_spec = {
    "1:KCoreAddons.KAboutData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KAboutData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void KAboutData_PythonToCpp_KAboutData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KAboutData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_KAboutData_PythonToCpp_KAboutData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KAboutData_TypeF()))
        return KAboutData_PythonToCpp_KAboutData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *KAboutData_PTR_CppToPython_KAboutData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KAboutData_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_KAboutData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *KAboutData_COPY_CppToPython_KAboutData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::KAboutData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_KAboutData_TypeF(), new ::KAboutData(*source), true, true);
}

// Python to C++ copy conversion.
static void KAboutData_PythonToCpp_KAboutData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::KAboutData *>(cppOut) = *reinterpret_cast< ::KAboutData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_KAboutData_PythonToCpp_KAboutData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_KAboutData_TypeF()))
        return KAboutData_PythonToCpp_KAboutData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KAboutData_SignatureStrings[] = {
    "1:KCoreAddons.KAboutData(self,other:KCoreAddons.KAboutData,*:KeywordOnly=None,displayName:QString=None,productName:QString=None,componentName:QString=None,programLogo:QVariant=None,shortDescription:QString=None,homepage:QString=None,bugAddress:QString=None,version:QString=None,otherText:QString=None,authors:QList[KCoreAddons.KAboutPerson]=None,credits:QList[KCoreAddons.KAboutPerson]=None,translators:QList[KCoreAddons.KAboutPerson]=None,components:QList[KCoreAddons.KAboutComponent]=None,licenses:QList[KCoreAddons.KAboutLicense]=None,copyrightStatement:QString=None,desktopFileName:QString=None)",
    "0:KCoreAddons.KAboutData(self,componentName:QString={},displayName:QString={},version:QString={},*:KeywordOnly=None,displayName:QString=None,productName:QString=None,componentName:QString=None,programLogo:QVariant=None,shortDescription:QString=None,homepage:QString=None,bugAddress:QString=None,version:QString=None,otherText:QString=None,authors:QList[KCoreAddons.KAboutPerson]=None,credits:QList[KCoreAddons.KAboutPerson]=None,translators:QList[KCoreAddons.KAboutPerson]=None,components:QList[KCoreAddons.KAboutComponent]=None,licenses:QList[KCoreAddons.KAboutLicense]=None,copyrightStatement:QString=None,desktopFileName:QString=None)",
    "KCoreAddons.KAboutData.aboutTranslationTeam()->QString",
    "2:KCoreAddons.KAboutData.addAuthor(self,author:KCoreAddons.KAboutPerson)->KCoreAddons.KAboutData",
    "1:KCoreAddons.KAboutData.addAuthor(self,name:QString,task:QString,emailAddress:QString,webAddress:QString,kdeStoreUsername:QString)->KCoreAddons.KAboutData",
    "0:KCoreAddons.KAboutData.addAuthor(self,name:QString,task:QString=QString(),emailAddress:QString=QString(),webAddress:QString=QString(),avatarUrl:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl())->KCoreAddons.KAboutData",
    "2:KCoreAddons.KAboutData.addComponent(self,component:KCoreAddons.KAboutComponent)->KCoreAddons.KAboutData",
    "1:KCoreAddons.KAboutData.addComponent(self,name:QString,description:QString=QString(),version:QString=QString(),webAddress:QString=QString(),licenseKey:KCoreAddons.KAboutLicense.LicenseKey=KAboutLicense.Unknown)->KCoreAddons.KAboutData",
    "0:KCoreAddons.KAboutData.addComponent(self,name:QString,description:QString,version:QString,webAddress:QString,pathToLicenseFile:QString)->KCoreAddons.KAboutData",
    "2:KCoreAddons.KAboutData.addCredit(self,person:KCoreAddons.KAboutPerson)->KCoreAddons.KAboutData",
    "1:KCoreAddons.KAboutData.addCredit(self,name:QString,task:QString,emailAddress:QString,webAddress:QString,kdeStoreUsername:QString)->KCoreAddons.KAboutData",
    "0:KCoreAddons.KAboutData.addCredit(self,name:QString,task:QString=QString(),emailAddress:QString=QString(),webAddress:QString=QString(),avatarUrl:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl())->KCoreAddons.KAboutData",
    "1:KCoreAddons.KAboutData.addLicense(self,licenseKey:KCoreAddons.KAboutLicense.LicenseKey)->KCoreAddons.KAboutData",
    "0:KCoreAddons.KAboutData.addLicense(self,licenseKey:KCoreAddons.KAboutLicense.LicenseKey,versionRestriction:KCoreAddons.KAboutLicense.VersionRestriction)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.addLicenseText(self,license:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.addLicenseTextFile(self,file:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.applicationData()->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.authors(self)->QList[KCoreAddons.KAboutPerson]",
    "KCoreAddons.KAboutData.bugAddress(self)->QString",
    "KCoreAddons.KAboutData.componentName(self)->QString",
    "KCoreAddons.KAboutData.components(self)->QList[KCoreAddons.KAboutComponent]",
    "KCoreAddons.KAboutData.copyrightStatement(self)->QString",
    "KCoreAddons.KAboutData.credits(self)->QList[KCoreAddons.KAboutPerson]",
    "KCoreAddons.KAboutData.customAuthorPlainText(self)->QString",
    "KCoreAddons.KAboutData.customAuthorRichText(self)->QString",
    "KCoreAddons.KAboutData.customAuthorTextEnabled(self)->bool",
    "KCoreAddons.KAboutData.desktopFileName(self)->QString",
    "KCoreAddons.KAboutData.displayName(self)->QString",
    "KCoreAddons.KAboutData.fromAppStreamFile(appStreamFileName:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.fromAppStreamForApplication()->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.fromAppStreamId(applicationId:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.homepage(self)->QString",
    "KCoreAddons.KAboutData.internalBugAddress(self)->char*",
    "KCoreAddons.KAboutData.internalProductName(self)->char*",
    "KCoreAddons.KAboutData.internalProgramName(self)->char*",
    "KCoreAddons.KAboutData.internalVersion(self)->char*",
    "KCoreAddons.KAboutData.licenses(self)->QList[KCoreAddons.KAboutLicense]",
    "KCoreAddons.KAboutData.organizationDomain(self)->QString",
    "KCoreAddons.KAboutData.otherText(self)->QString",
    "KCoreAddons.KAboutData.processCommandLine(self,parser:PySide6.QtCore.QCommandLineParser)",
    "KCoreAddons.KAboutData.productName(self)->QString",
    "KCoreAddons.KAboutData.programLogo(self)->QVariant",
    "KCoreAddons.KAboutData.setApplicationData(aboutData:KCoreAddons.KAboutData)",
    "KCoreAddons.KAboutData.setBugAddress(self,bugAddress:typing.Union[PySide6.QtCore.QByteArray, char*])->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setComponentName(self,componentName:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setCopyrightStatement(self,copyrightStatement:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setCustomAuthorText(self,plainText:QString,richText:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setDesktopFileName(self,desktopFileName:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setDisplayName(self,displayName:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setHomepage(self,homepage:QString)->KCoreAddons.KAboutData",
    "1:KCoreAddons.KAboutData.setLicense(self,licenseKey:KCoreAddons.KAboutLicense.LicenseKey)->KCoreAddons.KAboutData",
    "0:KCoreAddons.KAboutData.setLicense(self,licenseKey:KCoreAddons.KAboutLicense.LicenseKey,versionRestriction:KCoreAddons.KAboutLicense.VersionRestriction)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setLicenseText(self,license:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setLicenseTextFile(self,file:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setOrganizationDomain(self,domain:typing.Union[PySide6.QtCore.QByteArray, char*])->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setOtherText(self,otherText:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setProductName(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setProgramLogo(self,image:QVariant)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setShortDescription(self,shortDescription:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setTranslator(self,name:QString,emailAddress:QString)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setVersion(self,version:typing.Union[PySide6.QtCore.QByteArray, char*])->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.setupCommandLine(self,parser:PySide6.QtCore.QCommandLineParser)->bool",
    "KCoreAddons.KAboutData.shortDescription(self)->QString",
    "KCoreAddons.KAboutData.translators(self)->QList[KCoreAddons.KAboutPerson]",
    "KCoreAddons.KAboutData.unsetCustomAuthorText(self)->KCoreAddons.KAboutData",
    "KCoreAddons.KAboutData.version(self)->QString",
    "KCoreAddons.KAboutData.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t KAboutData_SignatureByteSize = 1036;
static constexpr uint8_t KAboutData_SignatureBytes[1036] = {
    0x78, 0xda, 0xed, 0x58, 0x4f, 0x4f, 0xdb, 0x30, 0x14, 0xbf, 0xf3, 0x29, 0x38, 0xb6, 0x28, 0xab,
    0x60, 0x87, 0x1d, 0x22, 0x75, 0x52, 0x81, 0x4d, 0x43, 0x54, 0xd0, 0xd2, 0x96, 0x0b, 0x42, 0x95,
    0x9b, 0x98, 0xd6, 0x6a, 0x62, 0x47, 0xb6, 0x0b, 0xcb, 0xa6, 0x7d, 0xf7, 0x39, 0x89, 0x93, 0x26,
    0x4e, 0x9c, 0x38, 0x29, 0x20, 0x0e, 0x9c, 0xda, 0xd8, 0x7e, 0xbf, 0xf7, 0xfc, 0xfe, 0x3f, 0x9f,
    0xd9, 0xd7, 0x17, 0x84, 0xc2, 0x91, 0xeb, 0x12, 0xcc, 0x06, 0xd7, 0xa3, 0x15, 0xd9, 0xf1, 0x4b,
    0xc0, 0x41, 0x8f, 0x41, 0xef, 0xc9, 0x22, 0x7c, 0x03, 0xa9, 0xe6, 0x84, 0x75, 0x62, 0x5f, 0xc3,
    0xf0, 0x85, 0x50, 0xf7, 0x16, 0x7b, 0xe1, 0xf0, 0x86, 0x60, 0x68, 0xb9, 0x88, 0x05, 0x1e, 0x08,
    0x6f, 0x80, 0x0f, 0xed, 0xe9, 0x8c, 0x53, 0x84, 0xd7, 0xc9, 0x46, 0x40, 0x89, 0xbb, 0x73, 0x78,
    0x79, 0xc3, 0x21, 0x7e, 0x20, 0x7e, 0x31, 0xaf, 0xa4, 0x59, 0x53, 0xe0, 0x8f, 0xc9, 0x9a, 0xd8,
    0xd3, 0x7b, 0x40, 0x11, 0xc0, 0x3c, 0xd9, 0x61, 0x1b, 0x42, 0xf9, 0x25, 0x64, 0x0e, 0x45, 0x01,
    0x47, 0x04, 0x17, 0xe9, 0x36, 0xc4, 0x87, 0x01, 0x58, 0x2b, 0x68, 0xab, 0xdd, 0x5a, 0x5c, 0x81,
    0x42, 0xc6, 0x8a, 0xeb, 0xcf, 0x90, 0xb2, 0x12, 0x44, 0x7c, 0xef, 0x39, 0xfc, 0xcd, 0x8b, 0xcb,
    0x60, 0xc7, 0x05, 0x67, 0x01, 0x30, 0x46, 0x8c, 0x3f, 0x94, 0xd5, 0x32, 0x11, 0x58, 0x04, 0x3f,
    0xca, 0x9b, 0x51, 0xe8, 0x22, 0x6e, 0x78, 0x98, 0x53, 0x80, 0x99, 0x07, 0xb8, 0x39, 0x7a, 0xaa,
    0x37, 0xfd, 0xf9, 0x8b, 0xf4, 0x88, 0x24, 0xf1, 0x90, 0x03, 0x31, 0x83, 0x7a, 0x82, 0x71, 0x72,
    0x20, 0xe3, 0x10, 0x84, 0x14, 0xad, 0x37, 0x7c, 0xc6, 0x01, 0x87, 0xbe, 0xc0, 0x29, 0x2a, 0xc3,
    0x85, 0x6c, 0xcb, 0x49, 0xf0, 0x13, 0x79, 0xb0, 0x64, 0xbb, 0xfe, 0xd1, 0x69, 0xad, 0x5f, 0x55,
    0x5b, 0xfd, 0xef, 0xbf, 0x4a, 0x07, 0x12, 0xcb, 0xaa, 0x91, 0xc4, 0xd2, 0xa7, 0xf7, 0x7d, 0x7a,
    0x9f, 0xd6, 0xfb, 0xaa, 0x7d, 0x6f, 0x00, 0xa2, 0x7f, 0x73, 0x79, 0x59, 0xa1, 0xf6, 0x39, 0x04,
    0x7e, 0xaf, 0xff, 0xe5, 0xbb, 0x24, 0x3e, 0xfa, 0x6a, 0xeb, 0x08, 0x5d, 0x77, 0x14, 0x6b, 0x3f,
    0x71, 0xdf, 0xc4, 0x12, 0xb6, 0x4e, 0x49, 0x02, 0xb1, 0x1a, 0xe7, 0xe8, 0xcc, 0x90, 0x01, 0xce,
    0x5d, 0xc9, 0xe2, 0x80, 0x6d, 0xb3, 0x0f, 0xe8, 0x03, 0xe4, 0x29, 0xae, 0x64, 0xbd, 0xc0, 0x95,
    0xba, 0xb4, 0x75, 0xe1, 0x4c, 0xd8, 0x13, 0x2e, 0x18, 0xa4, 0x79, 0x34, 0xbd, 0x6c, 0xa7, 0x87,
    0xca, 0x36, 0x94, 0xbf, 0xbd, 0x7e, 0xa5, 0x94, 0xb9, 0xed, 0xb2, 0xbc, 0xb9, 0x4d, 0xf0, 0x2c,
    0x98, 0xd2, 0x05, 0xf5, 0x6c, 0x1e, 0x06, 0x62, 0x69, 0xb0, 0xc0, 0xc2, 0x54, 0x0f, 0x93, 0x70,
    0x86, 0x5c, 0xf8, 0x6d, 0x30, 0xe5, 0x91, 0x94, 0x83, 0xa9, 0x38, 0x60, 0x1d, 0x4b, 0xaa, 0xc7,
    0x61, 0xf4, 0xd9, 0xeb, 0xeb, 0x2f, 0x57, 0x67, 0xd9, 0xcc, 0x53, 0x95, 0xdc, 0x64, 0xd7, 0x38,
    0x75, 0x37, 0x13, 0x2b, 0x9c, 0x0a, 0x9a, 0x74, 0x2b, 0x12, 0xca, 0x5e, 0x29, 0x6a, 0x9e, 0x30,
    0xd4, 0xa5, 0x0c, 0x3a, 0x91, 0x29, 0x6d, 0x6d, 0xc0, 0x0d, 0xc6, 0xd9, 0xa1, 0x61, 0x71, 0x63,
    0x81, 0xb7, 0x98, 0xbc, 0xe0, 0x6e, 0x2e, 0xd3, 0xf2, 0xae, 0xea, 0x0d, 0xab, 0x7c, 0x3a, 0x00,
    0x7c, 0x33, 0x27, 0x52, 0xba, 0x28, 0xf2, 0x9b, 0x9d, 0xba, 0xd6, 0xee, 0x71, 0x8a, 0x4c, 0xc4,
    0x0b, 0xe2, 0xc0, 0x7d, 0xe5, 0x88, 0xce, 0x33, 0xf8, 0x68, 0x11, 0x6d, 0x24, 0xdb, 0x47, 0x8e,
    0xe8, 0x3a, 0xc5, 0x4b, 0x17, 0x49, 0x6e, 0xd7, 0x32, 0x06, 0xba, 0xa9, 0xf3, 0x10, 0x8e, 0xa9,
    0xeb, 0xdf, 0x41, 0x26, 0xee, 0xee, 0xc4, 0x51, 0xa1, 0xa7, 0xbb, 0x2f, 0x1d, 0xd6, 0x4b, 0xdc,
    0x28, 0x6f, 0xd4, 0x64, 0x14, 0x64, 0x6e, 0x76, 0x2a, 0x23, 0xcc, 0x28, 0x38, 0x13, 0xdc, 0x27,
    0xa3, 0x30, 0xd5, 0x81, 0x06, 0x81, 0x90, 0x2b, 0x2e, 0xd5, 0x71, 0xef, 0xd8, 0x1e, 0x20, 0x69,
    0x99, 0x62, 0x51, 0xa2, 0x3a, 0x5f, 0xdf, 0xdb, 0xe8, 0x50, 0xf6, 0xcd, 0x5b, 0x06, 0x24, 0x1b,
    0x06, 0x0d, 0x41, 0xa1, 0xad, 0x6c, 0x4b, 0xd3, 0x28, 0xed, 0xbe, 0xb3, 0xd2, 0x63, 0xa9, 0xcd,
    0x93, 0xa9, 0x10, 0x49, 0xd7, 0x78, 0xa0, 0xbe, 0x9c, 0x1d, 0xe3, 0xc4, 0x4f, 0x7a, 0x86, 0x89,
    0x07, 0x10, 0xce, 0xdc, 0xcc, 0x40, 0x82, 0x1c, 0xed, 0x1d, 0x72, 0x36, 0x1d, 0x49, 0x23, 0xb2,
    0x1f, 0x18, 0xac, 0x3c, 0xe8, 0xa6, 0xd4, 0x2b, 0x42, 0x3c, 0x1d, 0xa9, 0xd2, 0x4d, 0x1a, 0x32,
    0xcc, 0xcd, 0x1b, 0x86, 0x14, 0x4f, 0x54, 0x08, 0x18, 0x04, 0xe2, 0x90, 0xe8, 0x3c, 0xe3, 0x20,
    0x01, 0xf9, 0xaf, 0x1b, 0xa3, 0xb4, 0x6e, 0x84, 0x4d, 0xe8, 0x68, 0x1f, 0x3c, 0xbd, 0xc3, 0xc0,
    0xae, 0xdc, 0x5e, 0x2e, 0x12, 0xaf, 0xdc, 0xce, 0x22, 0xa6, 0xb3, 0x91, 0xa1, 0xb6, 0x10, 0xe6,
    0x51, 0xa9, 0xf3, 0xce, 0x4b, 0xf1, 0xe7, 0x6c, 0x00, 0x3d, 0x69, 0x22, 0x9b, 0xec, 0xa7, 0xbe,
    0xb6, 0x74, 0xd1, 0xe4, 0xd7, 0x9a, 0x4e, 0x66, 0x66, 0x23, 0x9a, 0x74, 0x1a, 0x6a, 0x8a, 0xb4,
    0x74, 0x28, 0xd2, 0xe1, 0x10, 0xba, 0x06, 0x18, 0xfd, 0x49, 0x52, 0x24, 0x11, 0x35, 0x1a, 0x1b,
    0xea, 0x36, 0x9b, 0x31, 0x0d, 0xcf, 0x8b, 0x71, 0xd8, 0x11, 0x06, 0x10, 0xb9, 0xc7, 0x07, 0x58,
    0xa4, 0x7a, 0x2c, 0xf3, 0x7b, 0x00, 0xa8, 0xe8, 0x47, 0x6c, 0xb5, 0x96, 0xe7, 0xce, 0x4d, 0xe2,
    0x13, 0xfd, 0x1a, 0x60, 0xd5, 0x4a, 0xcd, 0xa2, 0xa4, 0x93, 0x79, 0x46, 0x21, 0x07, 0x74, 0x1d,
    0x09, 0x83, 0x7c, 0xa4, 0xd4, 0x12, 0x90, 0x6e, 0x6a, 0xaa, 0x7a, 0xbf, 0x06, 0x4b, 0x71, 0xc8,
    0xfc, 0x74, 0x5f, 0xdb, 0xe1, 0x9c, 0x87, 0x1c, 0x8e, 0x28, 0x05, 0xa1, 0x75, 0x1c, 0x7b, 0xc7,
    0x63, 0xeb, 0x08, 0x12, 0xcc, 0x2f, 0x4a, 0xc5, 0xa5, 0xfa, 0x19, 0xa3, 0x1b, 0x76, 0x65, 0xe1,
    0xa8, 0x99, 0xc6, 0x3b, 0x71, 0x51, 0x12, 0xb5, 0xf4, 0xa4, 0xb4, 0x52, 0x64, 0xad, 0x28, 0x95,
    0xf9, 0xff, 0x10, 0x5e, 0x97, 0x15, 0x99, 0x5d, 0xf7, 0x78, 0xd0, 0x09, 0x5f, 0xa9, 0x01, 0x55,
    0x8f, 0x50, 0x5d, 0x70, 0x7f, 0xe5, 0x53, 0x65, 0xe9, 0x51, 0xa9, 0x43, 0x5b, 0x2c, 0x30, 0xdf,
    0xb9, 0x2d, 0x3e, 0x90, 0xe3, 0xbb, 0xb7, 0xc5, 0x7b, 0x79, 0x5f, 0xaf, 0x2d, 0x2e, 0x62, 0xbe,
    0x52, 0x5b, 0x2c, 0x40, 0x6f, 0xab, 0xf3, 0xbe, 0xe5, 0xc6, 0xff, 0xdf, 0x21, 0x0b, 0xdd, 0x16,
    0xea, 0x47, 0xf9, 0xc9, 0xb2, 0x0b, 0xa6, 0x5a, 0xb0, 0x93, 0xc1, 0xf4, 0xed, 0xef, 0x32, 0x51,
    0x0a, 0x8a, 0x85, 0xfc, 0x38, 0xd6, 0x64, 0x51, 0xe9, 0x02, 0x39, 0x53, 0xde, 0x88, 0x13, 0x5c,
    0xdd, 0xcb, 0x71, 0x17, 0x0e, 0xf3, 0xec, 0xcd, 0xb6, 0x62, 0x88, 0xaf, 0x9a, 0xd6, 0xbb, 0x30,
    0xc9, 0xb7, 0x34, 0xd9, 0x0b, 0xcd, 0xdb, 0x1b, 0x64, 0x17, 0x74, 0xef, 0x33, 0xea, 0x1b, 0x7d,
    0x56, 0x65, 0x97, 0xe6, 0x96, 0x23, 0xf7, 0x40, 0x7e, 0xe0, 0x6c, 0xb4, 0xc3, 0xba, 0x02, 0xd8,
    0x5a, 0x51, 0xcf, 0xc5, 0x7e, 0xb3, 0xe1, 0x0a, 0xcb, 0x65, 0x54, 0xc4, 0x97, 0xcb, 0xf4, 0xb8,
    0xb4, 0xe2, 0x72, 0x26, 0x3e, 0x8f, 0xfe, 0x03, 0xcd, 0x24, 0x47, 0xf5
};
#endif

PyTypeObject *init_KAboutData(PyObject *module)
{
    auto &typeStruct = SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KAboutData_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        module,
        "KAboutData",
        "KAboutData",
        &Sbk_KAboutData_spec,
        &Shiboken::callCppDestructor< ::KAboutData >,
        Sbk_KAboutData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KAboutData_SignatureStrings);
#else
    InitSignatureBytes(pyType, KAboutData_SignatureBytes, KAboutData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KAboutData_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        KAboutData_PythonToCpp_KAboutData_PTR,
        is_KAboutData_PythonToCpp_KAboutData_PTR_Convertible,
        KAboutData_PTR_CppToPython_KAboutData,
        KAboutData_COPY_CppToPython_KAboutData);

    Shiboken::Conversions::registerConverterName(converter, "KAboutData");
    Shiboken::Conversions::registerConverterName(converter, "KAboutData*");
    Shiboken::Conversions::registerConverterName(converter, "KAboutData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KAboutData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        KAboutData_PythonToCpp_KAboutData_COPY,
        is_KAboutData_PythonToCpp_KAboutData_COPY_Convertible);

    qRegisterMetaType< ::KAboutData >("KAboutData");

    return pyType;
}
